@@ -1,5 +1,5 @@
 package Date::QuarterOfYear;
-$Date::QuarterOfYear::VERSION = '0.02';
+$Date::QuarterOfYear::VERSION = '0.03';
 use 5.006;
 use strict;
 use warnings;
@@ -108,7 +108,7 @@ quarter number for a given date.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Date-QuarterOfYear>
+L<https://github.com/neilb/Date-QuarterOfYear>
 
 =head1 AUTHOR
 
